# Credits

## Core team

* Wai Yi Anthony Leung ([anthony@askanna.io](anthony@askanna.io))
* Robbert Bos ([robbert@askanna.io](robbert@askanna.io))

## Contributors

* [Antonis Sgouros](https://gitlab.com/porfyros)
* [Federico Jaramillo](https://gitlab.com/jmfederico)

Your name here? [Open a ticket](https://gitlab.com/askanna/askanna-python/issues) and start adding features to AskAnna!
